
def read_fasta(filename):
    """Legge un file fasta e restituisce una sequenza."""
    f = open(filename)
    # skip header
    f.readline()
    seq = ""
    for row in f:
        seq += row.strip()
    f.close()
    return seq

def read_codon_table(filename):
    """Legge una tabella di occorrenze di codoni 
e la restituisce come dizionario."""
    f = open(filename)
    diz = {}
    for row in f:
        data = row.split()
        diz[data[0]] = float(data[1])
    f.close()
    return diz

def compute_codon_table(seq):
    """Calcola il dizionario di occorrenze dei codoni 
in una sequenza di ingresso."""
    diz = {}
    # calcolo occorrenze dei codoni
    for i in range(0, len(seq), 3):
        codon = seq[i:i+3]
        if not codon in diz:
            diz[codon] = 1
        else:
            diz[codon] += 1
    # normalizzo le occorrenze
    num_codons = len(seq) / 3
    for codon in diz:
        diz[codon] /= num_codons
    return diz

def print_codon_tables(genome, gene):
    """Stampa le occorrenze dei codoni nel genoma e nel gene in ingresso."""
    # stampa intestazione
    print("Codon\tGenome\tGene")
    for codon in genome:
        genome_freq = genome[codon]
        gene_freq = gene.get(codon, 0)
        print("%s\t%.4f\t%.4f" %(codon,genome_freq,gene_freq))

fastafile = input("Inserire nome file fasta: ")
tablefile = input("Inserire nome file frequenze codoni: ")
s = read_fasta(fastafile)
diz_genome = read_codon_table(tablefile)
diz_gene = compute_codon_table(s)
print_codon_tables(diz_genome, diz_gene)
